package hu.uniobuda.nik.googlemapsv2demo;

import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.GooglePlayServicesUtil;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.GoogleMapOptions;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.CameraPosition;
import com.google.android.gms.maps.model.LatLng;

import android.location.Location;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

public class MainActivity extends FragmentActivity {

	SupportMapFragment mapFragment;
	GoogleMap googleMap;
	GoogleMapOptions googleMapOptions;
	MarkerOverlay markersOverlay;
	
	Button moveButton, zoomInButton, zoomToButton, cameraToButton;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		// Initial ----------------------------------------------------------
		if(GooglePlayServicesUtil.isGooglePlayServicesAvailable(this) != ConnectionResult.SUCCESS)
			Toast.makeText(this, "Google Play Service nem érhető el vagy elavult!", Toast.LENGTH_LONG).show();
		
		mapFragment = (SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.map);
		googleMap = mapFragment.getMap();
		googleMap.setMyLocationEnabled(true);
		
		
		// Marker handling --------------------------------------------------
		markersOverlay = new MarkerOverlay(googleMap);
		googleMap.setOnMyLocationChangeListener(new GoogleMap.OnMyLocationChangeListener() {
			public void onMyLocationChange(Location location) {
				
				markersOverlay.addMarker(
						new LatLng(location.getLatitude(), location.getLongitude()), 
						null, 
						null, 
						R.drawable.point);
				
			}
		});
		
		
		// Mozgatások -------------------------------------------------------
		// Kamera mozgatása adott pozícióba
		moveButton = (Button)findViewById(R.id.move);
		moveButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				
				googleMap.moveCamera(
						CameraUpdateFactory.newLatLngZoom(
								new LatLng(47.533599, 19.033899), 
								14
								));
				
			}
		});
		
		
		// Közelítés, nagyítás
		zoomInButton = (Button)findViewById(R.id.zoomIn);
		zoomInButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				
				googleMap.animateCamera(CameraUpdateFactory.zoomIn());
				
			}
		});
		
		// Közeítés, nagyítás adott szintre, animálva
		zoomToButton = (Button)findViewById(R.id.zoomTo);
		zoomToButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				
				googleMap.animateCamera(CameraUpdateFactory.zoomTo(10), 2000, null);
				
			}
		});
		
		// Kamera mozgatása tetszőleges helyre és nézőpontba
		cameraToButton = (Button)findViewById(R.id.cameraTo);
		cameraToButton.setOnClickListener(new OnClickListener() {
			public void onClick(View arg0) {
				
				CameraPosition camPos = new CameraPosition.Builder()
						.target(new LatLng(47.533599, 19.033899))
						.zoom(17)
						.bearing(90)
						.tilt(30)
						.build();
				googleMap.animateCamera(
						CameraUpdateFactory.newCameraPosition(camPos),
						5000, 	
						new GoogleMap.CancelableCallback() {
							public void onFinish() {
								Toast.makeText(MainActivity.this, "Pozícionálva :)", Toast.LENGTH_SHORT).show();
							}
							
							public void onCancel() {
								Toast.makeText(MainActivity.this, "Megszakítva!", Toast.LENGTH_SHORT).show();
							}
						});
				
			}
		});

		
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

}
